```{include} ../README.md
---
end-before: <!-- github-only -->
---
```

[license]: license
[contributor guide]: contributing
[command-line reference]: reference
[vardef client]: ../src/dapla_metadata/variable_definitions/generated/README.md

```{toctree}
---
hidden:
maxdepth: 1
---

reference
vardef_client
contributing
Code of Conduct <codeofconduct>
License <license>
Changelog <https://github.com/statisticsnorway/dapla-toolbelt-metadata/releases>
```
